job "frontend" {
  datacenters = ["dc1"]
  type = "service"

  group "traefik" {
    task "server" {
      driver = "docker"

      config {
        image = "amd64/traefik:1.7.20"
        readonly_rootfs = true
        network_mode = "host"
        volumes = [
          "secrets/traefik.toml:/etc/traefik/traefik.toml",
        ]
      }

      resources {
        memory = 265
      }

      service {
        tags = [
          "https", 
          "frontend",
          "(diplonat (tcp_port 80 443))"
        ]
        port = 443
        address_mode = "driver"
        name = "traefik"
        check {
          type = "http"
          protocol = "http"
          port = 8082
          address_mode = "driver"
          path = "/ping"
          interval = "60s"
          timeout = "5s"
          check_restart {
            limit = 3
            grace = "90s"
            ignore_warnings = false
          }
        }
      }
      
      template {
        data = "{{ key \"configuration/traefik/traefik.toml\" }}"
        destination = "secrets/traefik.toml"
      }
    }
  }
}

